@@ -26,13 +26,18 @@ from fedmsg.tests.test_meta import Base
 
 class TestKojiBuildTag(Base):
     expected_title = "buildsys.tag (unsigned)"
-    expected_subti = 'stage-4.1.1-3.fc18 tagged f18-updates-testing-pending'
+    expected_subti = "ralph's stage-4.1.1-3.fc18 tagged " + \
+        "f18-updates-testing-pending"
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
         "Artwork_DesignService_koji-icon-48.png"
     expected_packages = set(['stage'])
-    expected_objects = set(['builds/stage/4.1.1/3.fc18'])
-    #expected_link = "http://koji.fedoraproject.org/koji/" + \
-    #    "buildinfo?buildID=342074"
+    expected_usernames = set(['ralph', 'bodhi'])
+    expected_objects = set([
+        'koji/builds/stage/4.1.1/3.fc18',
+        'koji/tags/f18-updates-testing-pending',
+    ])
+    expected_link = "https://koji.fedoraproject.org/koji/" + \
+        "taginfo?tagID=216"
     msg = {
         "username": "apache",
         "i": 1,
@@ -43,19 +48,27 @@ class TestKojiBuildTag(Base):
             "tag": "f18-updates-testing-pending",
             "name": "stage",
             "version": "4.1.1",
-            "user": "bodhi"
+            "user": "bodhi",
+            "owner": "ralph",
+            "tag_id": 216,
         }
     }
 
+
 class TestKojiBuildUnTag(Base):
     expected_title = "buildsys.untag (unsigned)"
-    expected_subti = 'globus-gram-job-manager-sge-1.5-2.fc16 untagged from f16-updates-pending'
+    expected_subti = "ralph's globus-gram-job-manager-sge-1.5-2.fc16 " + \
+        "untagged from f16-updates-pending"
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
         "Artwork_DesignService_koji-icon-48.png"
     expected_packages = set(['globus-gram-job-manager-sge'])
-    expected_objects = set(['builds/globus-gram-job-manager-sge/1.5/2.fc16'])
-    #expected_link = "http://koji.fedoraproject.org/koji/" + \
-    #    "buildinfo?buildID=342074"
+    expected_usernames = set(['ralph', 'bodhi'])
+    expected_objects = set([
+        'koji/builds/globus-gram-job-manager-sge/1.5/2.fc16',
+        'koji/tags/f16-updates-pending',
+    ])
+    expected_link = "https://koji.fedoraproject.org/koji/" + \
+        "taginfo?tagID=216"
     msg = {
         "username": "apache",
         "i": 85,
@@ -66,19 +79,25 @@ class TestKojiBuildUnTag(Base):
             "tag": "f16-updates-pending",
             "name": "globus-gram-job-manager-sge",
             "version": "1.5",
-            "user": "bodhi"
+            "user": "bodhi",
+            "owner": "ralph",
+            "tag_id": 216,
         }
     }
 
+
 class TestKojiBuildStateChangeStart(Base):
     expected_title = "buildsys.build.state.change (unsigned)"
-    expected_subti = 'eclipse-ptp-6.0.3-1.fc19 started building'
+    expected_subti = "ralph's eclipse-ptp-6.0.3-1.fc19 started building"
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
         "Artwork_DesignService_koji-icon-48.png"
+    expected_usernames = set(['ralph'])
     expected_packages = set(['eclipse-ptp'])
-    expected_objects = set(['builds/eclipse-ptp/6.0.3/1.fc19'])
-    #expected_link = "http://koji.fedoraproject.org/koji/" + \
-    #    "buildinfo?buildID=342074"
+    expected_objects = set([
+        'koji/builds/eclipse-ptp/6.0.3/1.fc19'
+    ])
+    expected_link = "https://koji.fedoraproject.org/koji/" + \
+        "buildinfo?buildID=12345"
     msg = {
         "username": "apache",
         "i": 1,
@@ -90,21 +109,25 @@ class TestKojiBuildStateChangeStart(Base):
             "attribute": "state",
             "version": "6.0.3",
             "release": "1.fc19",
-            "new": 0
+            "new": 0,
+            "owner": "ralph",
+            "build_id": 12345,
         }
     }
 
 
 class TestKojiBuildStateChangeFail(Base):
     expected_title = "buildsys.build.state.change (unsigned)"
-    expected_subti = 'eclipse-ptp-6.0.3-1.fc19 failed to build'
+    expected_subti = "rmattes's eclipse-ptp-6.0.3-1.fc19 failed to build"
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
         "Artwork_DesignService_koji-icon-48.png"
     expected_packages = set(['eclipse-ptp'])
-    #expected_usernames = set(['rmattes'])
-    expected_objects = set(['builds/eclipse-ptp/6.0.3/1.fc19'])
-    #expected_link = "http://koji.fedoraproject.org/koji/" + \
-    #    "buildinfo?buildID=342074"
+    expected_usernames = set(['rmattes'])
+    expected_objects = set([
+        'koji/builds/eclipse-ptp/6.0.3/1.fc19',
+    ])
+    expected_link = "https://koji.fedoraproject.org/koji/" + \
+        "buildinfo?buildID=12345"
     msg = {
         "username": "apache",
         "i": 1,
@@ -116,7 +139,9 @@ class TestKojiBuildStateChangeFail(Base):
             "attribute": "state",
             "version": "6.0.3",
             "release": "1.fc19",
-            "new": 3
+            "new": 3,
+            "owner": "rmattes",
+            "build_id": 12345,
         }
     }
 
@@ -128,14 +153,20 @@ class TestKojiRepoInit(Base):
         "Artwork_DesignService_koji-icon-48.png"
     expected_packages = set([])
     expected_usernames = set([])
-    expected_objects = set(['repos/f19-build'])
+    expected_objects = set([
+        'koji/repos/f19-build',
+    ])
+    expected_link = "https://koji.fedoraproject.org/koji/" + \
+        "taginfo?tagID=12345"
     msg = {
         "username": "apache",
         "i": 2,
         "timestamp": 1359655886.353586,
         "topic": "org.fedoraproject.prod.buildsys.repo.init",
         "msg": {
-            "tag": "f19-build"
+            "tag": "f19-build",
+            "tag_id": 12345,
+            "repo_id": 23456,
         }
     }
 
@@ -147,14 +178,20 @@ class TestKojiRepoDone(Base):
         "Artwork_DesignService_koji-icon-48.png"
     expected_packages = set([])
     expected_usernames = set([])
-    expected_objects = set(['repos/f19-build'])
+    expected_objects = set([
+        'koji/repos/f19-build',
+    ])
+    expected_link = "https://koji.fedoraproject.org/koji/" + \
+        "taginfo?tagID=12345"
     msg = {
         "username": "apache",
         "i": 2,
         "timestamp": 1359655886.353586,
         "topic": "org.fedoraproject.prod.buildsys.repo.done",
         "msg": {
-            "tag": "f19-build"
+            "tag": "f19-build",
+            "tag_id": 12345,
+            "repo_id": 23456,
         }
     }
 
